@@ -1,7 +1,7 @@
 g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3600),
                    desiredtz = "Europe/London",chunksize=c(),studyname=c(),
                    do.enmo = TRUE,do.lfenmo = FALSE,do.en = FALSE,
-                   do.bfen = FALSE,do.hfen=FALSE,do.hfenplus = FALSE,
+                   do.bfen = FALSE,do.hfen=FALSE,do.hfenplus = FALSE, do.mad = FALSE,
                    do.anglex=FALSE,do.angley=FALSE,do.anglez=FALSE,
                    do.enmoa = FALSE,
                    do.roll_med_acc_x=FALSE,do.roll_med_acc_y=FALSE,do.roll_med_acc_z=FALSE,
@@ -267,6 +267,7 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
                     do.en=do.en,
                     do.hfen=do.hfen,
                     do.hfenplus=do.hfenplus,
+                    do.mad=do.mad,
                     do.anglex=do.anglex,do.angley=do.angley,do.anglez=do.anglez,
                     do.roll_med_acc_x=do.roll_med_acc_x,do.roll_med_acc_y=do.roll_med_acc_y,do.roll_med_acc_z=do.roll_med_acc_z,
                     do.dev_roll_med_acc_x=do.dev_roll_med_acc_x,do.dev_roll_med_acc_y=do.dev_roll_med_acc_y,do.dev_roll_med_acc_z=do.dev_roll_med_acc_z,
@@ -306,4 +307,4 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
     }
     closeAllConnections()
   }
-}
\ No newline at end of file
+}
