@@ -156,6 +156,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   # if (length(which(ls() == "bout.metric")) == 0) bout.metric = 1
   if (length(which(ls() == "window.summary.size")) == 0) window.summary.size = 10
   if (length(which(ls() == "dayborder")) == 0)  dayborder = 0
+  if (length(which(ls() == "iglevels")) == 0)  iglevels = c()
   
   cat("\n   Help sustain GGIR into the future \n")
   cat("   Check out: https://www.movementdata.nl/how-to-help-sustain-ggir \n")
@@ -195,7 +196,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
             mvpadur=mvpadur,selectdaysfile=selectdaysfile,bout.metric=bout.metric,window.summary.size=window.summary.size,
             dayborder=dayborder,closedbout=closedbout,desiredtz=desiredtz,
             IVIS_windowsize_minutes = IVIS_windowsize_minutes,
-            IVIS_epochsize_seconds = IVIS_epochsize_seconds)
+            IVIS_epochsize_seconds = IVIS_epochsize_seconds, iglevels = iglevels)
   }
   if (dopart3 == TRUE) {
     cat('\n')
